@@ -268,27 +268,49 @@ class Factory:
         return self.get_instance(service_builder, service_name, instance_name, [], kwargs)
 
     def clickhouse_client(self, **kwargs) -> ch_d.Client:
+        r"""Create and return object of clickhouse client
+            :Keyword Arguments:
+                * *type* (``str``) -- postfix for secret and config name (clickhouse_TYPE). Default: None (clickhouse)
+            """
         service_name = "clickhouse_client"
         instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
-        scrts = self.secrets["clickhouse"]
-        cnfg = self.config["clickhouse"]
-        args = []
-        args.append(cnfg["url"] if "url" not in kwargs else kwargs["url"])
-        kwargs["port"] = cnfg["port"] if not ("port" in kwargs) else kwargs["port"]
-        kwargs["user"] = scrts["user"] if not ("user" in kwargs) else kwargs["user"]
-        kwargs["password"] = scrts["password"] if not ("password" in kwargs) else kwargs["password"]
-        kwargs["secure"] = True if "secure" not in kwargs else kwargs["secure"]
-        kwargs["verify"] = False if "verify" not in kwargs else kwargs["verify"]
-        return self.get_instance(ch_d.Client, service_name, instance_name, args, kwargs)
 
-    def aio_clickhouse(self, loop: AbstractEventLoop, **kwargs) -> ClickhouseAioClient:
-        service_name = "aio_clickhouse"
-        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
-        secrets = self.secrets["clickhouse"]
-        config = self.config["clickhouse"]
+        ch_type = None if not "type" in kwargs else kwargs["type"]
+        secrets = self._get_clickhouse_secrets(ch_type)
+        config = self._get_clickhouse_config(ch_type)
+
+        if "type" in kwargs.keys():
+            del kwargs["type"]
 
         args = []
         args.append(config["url"] if "url" not in kwargs else kwargs["url"])
+
+        kwargs["port"] = config["port"] if not ("port" in kwargs) else kwargs["port"]
+        kwargs["user"] = secrets["user"] if not ("user" in kwargs) else kwargs["user"]
+        kwargs["password"] = secrets["password"] if not ("password" in kwargs) else kwargs["password"]
+        kwargs["secure"] = True if "secure" not in kwargs else kwargs["secure"]
+        kwargs["verify"] = False if "verify" not in kwargs else kwargs["verify"]
+
+        return self.get_instance(ch_d.Client, service_name, instance_name, args, kwargs)
+
+    def aio_clickhouse(self, loop: AbstractEventLoop, **kwargs) -> ClickhouseAioClient:
+        r"""Create and return object of clickhouse client
+            :Keyword Arguments:
+                * *type* (``str``) -- postfix for secret and config name (clickhouse_TYPE). Default: None (clickhouse)
+            """
+        service_name = "aio_clickhouse"
+        instance_name = self.def_instance_name if not self.key_istance_name in kwargs else kwargs[self.key_istance_name]
+
+        ch_type = None if not "type" in kwargs else kwargs["type"]
+        secrets = self._get_clickhouse_secrets(ch_type)
+        config = self._get_clickhouse_config(ch_type)
+
+        if "type" in kwargs.keys():
+            del kwargs["type"]
+
+        args = []
+        args.append(config["url"] if "url" not in kwargs else kwargs["url"])
+
         kwargs["port"] = config["port"] if not ("port" in kwargs) else kwargs["port"]
         kwargs["user"] = secrets["user"] if not ("user" in kwargs) else kwargs["user"]
         kwargs["password"] = secrets["password"] if not ("password" in kwargs) else kwargs["password"]
@@ -299,6 +321,26 @@ class Factory:
 
         return self.get_instance(ClickhouseAioClient, service_name, instance_name, args, kwargs)
 
+    def _get_clickhouse_secrets(self, ch_type: str = None) -> dict:
+        if ch_type is None or ch_type == "":
+            return self.secrets["clickhouse"]
+
+        if f"clickhouse_{ch_type}" not in self.secrets:
+            self.secrets[f"clickhouse_{ch_type}"] = self._get_secrets(f"clickhouse_{ch_type}")
+
+        return self.secrets[f"clickhouse_{ch_type}"]
+
+    def _get_clickhouse_config(self, ch_type: str = None) -> dict:
+        if ch_type is None or ch_type == "":
+            return self.config["clickhouse"]
+
+        if f"clickhouse_{ch_type}" not in self.config:
+            consul = self.consul(instance_name="in_uses_for_factory")
+            consul_config = consul.kv[f"env/databases/clickhouse_{ch_type}"]
+            self.config[f"clickhouse_{ch_type}"] = json.loads(consul_config)
+
+        return self.config[f"clickhouse_{ch_type}"]
+
     def kafka_producer(self, **kwargs) -> KafkaProducer:
         def serialiser(v):
             return json.dumps(v).encode('utf-8')
