@@ -45,7 +45,7 @@ class AuthenticationBackend(BaseHTTPMiddleware):
             email = payload.get("email")
             tenants = payload.get("tenants", [])
             properties = payload.get("properties", {})
-            user = RequestUser(name=username, email=email, scope=scopes, tenants=tenants, properties=properties)
+            user = RequestUser(name=username, email=email, scopes=scopes, tenants=tenants, properties=properties)
             request.scope["user"] = user
             request.scope["auth"] = True
             response = await call_next(request)
